import React from 'react'
import { ContentItems } from '../Editing/Editing'
import { convertStringToEditorState } from '../../utils/editorStateManagment'
import CustomEditor from '../Editing/CustomEditor'

interface MonthlyNewsProps {
  onSave: () => Promise<void>
  onCancel: () => void
  header: string
  quote: string
  handleChange: (
    value: string,
    type: 'header' | 'quote' | 'question' | 'link'
  ) => void
  onDelete: (target: ContentItems) => void
}
const MonthlyNews: React.FC<MonthlyNewsProps> = ({
  onSave,
  onCancel,
  header,
  quote,
  handleChange,
  onDelete,
}: MonthlyNewsProps) => {
  return (
    <>
      <div className="subtitle">
        <p className="title">Informations du mois</p>
      </div>
      <div>
        <CustomEditor
          baseState={convertStringToEditorState(header)}
          handleChange={handleChange}
          editorType="header"
        />
        <div className="subtitle">
          <p className="title">Citation du mois</p>
        </div>
        <div>
          <CustomEditor
            baseState={convertStringToEditorState(quote)}
            handleChange={handleChange}
            editorType="quote"
          />
        </div>
        <div className="buttons">
          <button className="btnCancel" onClick={onCancel}>
            Annuler
          </button>
          <button className="btnValid" onClick={onSave}>
            Sauvegarder
          </button>
          <button className="btnDelete" onClick={() => onDelete('monthlyNews')}>
            Supprimer
          </button>
        </div>
      </div>
    </>
  )
}

export default MonthlyNews
